.. _python_module:

:mod:`fabtools.python`
----------------------

.. automodule:: fabtools.python

    .. seealso:: :ref:`python_setuptools_module` and :ref:`require_python_module`

    Virtual environments
    ~~~~~~~~~~~~~~~~~~~~

    .. autofunction:: virtualenv

    Installing pip
    ~~~~~~~~~~~~~~

    .. autofunction:: is_pip_installed
    .. autofunction:: install_pip

    Installing packages
    ~~~~~~~~~~~~~~~~~~~

    .. autofunction:: is_installed
    .. autofunction:: install
    .. autofunction:: install_requirements
